@@ -219,3 +219,9 @@ tidy.step_ts_impute <- function(x, ...) {
     res$id <- x$id
     res
 }
+
+#' @rdname required_pkgs.timetk
+#' @export
+required_pkgs.step_ts_impute <- function(x, ...) {
+    c("timetk")
+}
